@@ -123,6 +123,22 @@ class DjangoTestApp(TestApp):
                    url, params, headers, extra_environ, status,
                    upload_files, expect_errors, content_type)
 
+    def patch(self, url, params='', headers=None, extra_environ=None,
+             status=None, upload_files=None, expect_errors=False,
+             content_type=None, user=None):
+        extra_environ = self._update_environ(extra_environ, user)
+        return super(DjangoTestApp, self).patch(
+                   url, params, headers, extra_environ, status,
+                   upload_files, expect_errors, content_type)
+
+    def options(self, url, params='', headers=None, extra_environ=None,
+             status=None, upload_files=None, expect_errors=False,
+             content_type=None, user=None):
+        extra_environ = self._update_environ(extra_environ, user)
+        return super(DjangoTestApp, self).options(
+                   url, params, headers, extra_environ, status,
+                   upload_files, expect_errors, content_type)
+
     def delete(self, url, params='', headers=None, extra_environ=None,
              status=None, expect_errors=False,
              content_type=None, user=None):
