@@ -25,6 +25,10 @@ class DjangoWebtestResponse(TestResponse):
     def content(self):
         return self.body
 
+    @property
+    def url(self):
+        return self['location']
+
     @property
     def client(self):
         client = Client()
